summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/indi/indicom.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kstars/kstars/indi/indicom.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/indi/indicom.h')
-rw-r--r--kstars/kstars/indi/indicom.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/indi/indicom.h b/kstars/kstars/indi/indicom.h
index 726c7dcd..6f59a63d 100644
--- a/kstars/kstars/indi/indicom.h
+++ b/kstars/kstars/indi/indicom.h
@@ -169,13 +169,13 @@ void aberrate(double *RA, double *Dec);
*/
void precessFromAnyEpoch(double jd0, double jdf, double *RA, double *Dec);
/** \brief Calculate the apparent coordiantes for RA and Dec from any epoch to any epoch.
\param jd0 starting epoch.
\param jdf final epoch.
\param RA a pointer to a double containing the Right ascension in hours. The function stores the processed Right ascension back in this variable.
\param Dec a pointer to a double containing the delination in degrees. The function stores the processed delination back in this variable.
*/
-void apparentCoord(double jd0, double jdf, double *RA, double *Dec);
+void aptqparentCoord(double jd0, double jdf, double *RA, double *Dec);
/*@}*/
@@ -169,13 +169,13 @@ void aberrate(double *RA, double *Dec);
*/
void precessFromAnyEpoch(double jd0, double jdf, double *RA, double *Dec);
-/** \brief Calculate the apparent coordiantes for RA and Dec from any epoch to any epoch.
+/** \brief Calculate the aptqparent coordiantes for RA and Dec from any epoch to any epoch.
\param jd0 starting epoch.
\param jdf final epoch.